@@ -20,6 +20,7 @@
 
 import pygtk
 import os
+from xml.sax import saxutils
 pygtk.require('2.0')
 import gtk
 import hildon
@@ -46,7 +47,7 @@ class Maevies(hildon.StackableWindow):
         super(Maevies, self).__init__()
         self.set_title('Maevies - 0.1')
         self.connect('delete-event',
-                     lambda widget, event: gtk.main_quit())
+                     self.quit)
 
         self.add(self._create_contents())
         self.set_app_menu(self._create_app_menu())
@@ -98,6 +99,13 @@ class Maevies(hildon.StackableWindow):
             search_dialog.destroy()
         elif action == self.ACTION_ABOUT:
             about_dialog = AboutDialog(self)
+            about_dialog.set_logo(constants.APP_ICON)
+            about_dialog.set_name(constants.APP_NAME)
+            about_dialog.set_version(constants.APP_VERSION)
+            about_dialog.set_comments(constants.APP_DESCRIPTION)
+            about_dialog.set_authors(constants.APP_AUTHORS)
+            about_dialog.set_copyright(constants.APP_COPYRIGHT)
+            about_dialog.set_license(saxutils.escape(constants.APP_LICENSE))
             about_dialog.run()
             about_dialog.destroy()
 
@@ -117,6 +125,10 @@ class Maevies(hildon.StackableWindow):
     def run(self):
         gtk.main()
 
+    def quit(self, widget, event):
+        moviemanager.destroy()
+        gtk.main_quit()
+
 class SearchDialog(gtk.Dialog):
 
     TMDB_SEARCH = 0
@@ -196,22 +208,29 @@ class ResultsWindow(hildon.StackableWindow):
             WatcWindow(movie)
 
     def start_search(self, search_term, search_category):
-        self._show_banner(search_term, search_category)
+        self._show_banner(self._get_search_message(search_term, search_category))
         hildon.hildon_gtk_window_set_progress_indicator(self, True)
         moviemanager.query(search_term, search_category)
 
-    def _response_received_cb(self, movies):
-        self._movies_view.add_movies(movies)
+    def _response_received_cb(self, movies, error=None):
         hildon.hildon_gtk_window_set_progress_indicator(self, False)
+        if not error:
+            self._movies_view.add_movies(movies)
+        else:
+            self._show_banner(constants.DBUS_ERROR,
+                              constants.TIMEOUT_TIME_MILLIS * 5)
 
-    def _show_banner(self, search_term, search_category):
-        message = ('Searching on <i>%(category)s</i> for <i>%(term)s</i>' %
-                   {'category': SearchDialog.search_fields[search_category],
-                    'term' : search_term})
+    def _show_banner(self, message, timeout=constants.TIMEOUT_TIME_MILLIS):
         banner = hildon.hildon_banner_show_information_with_markup(self,
                                                                    'ignored',
                                                                    message)
-        banner.set_timeout(constants.TIMEOUT_TIME_MILLIS)
+        banner.set_timeout(timeout)
+
+    def _get_search_message(self, search_term, search_category):
+        message = ('Searching on <i>%(category)s</i> for <i>%(term)s</i>' %
+                   {'category': SearchDialog.search_fields[search_category],
+                    'term' : search_term})
+        return message
 
 class MoviesView(gtk.TreeView):
 
@@ -264,12 +283,77 @@ class MoviesListStore(gtk.ListStore):
 
 class AboutDialog(gtk.Dialog):
 
+    PADDING = 5
+
     def __init__(self, parent):
         super(AboutDialog, self).__init__(parent=parent,
                                           flags=gtk.DIALOG_DESTROY_WITH_PARENT)
-        self.set_title('About Maevies')
+        self._logo = gtk.Image()
+        self._name = ''
+        self._name_label = gtk.Label()
+        self._version = ''
+        self._comments_label = gtk.Label()
+        self._copyright_label = gtk.Label()
+        self._license_label = gtk.Label()
+        _license_alignment = gtk.Alignment(0, 0, 0, 1)
+        _license_alignment.add(self._license_label)
+        self._license_label.set_line_wrap(True)
 
-        self.show_all()
+        self._writers_caption = gtk.Label()
+        self._writers_caption.set_markup('<b>%s</b>' % 'Authors:')
+        _writers_caption = gtk.Alignment()
+        _writers_caption.add(self._writers_caption)
+        self._writers_label = gtk.Label()
+        self._writers_contents = gtk.VBox(False, 0)
+        self._writers_contents.pack_start(_writers_caption)
+        _writers_alignment = gtk.Alignment(0.2, 0, 0, 1)
+        _writers_alignment.add(self._writers_label)
+        self._writers_contents.pack_start(_writers_alignment)
+
+        _contents = gtk.VBox(False, 0)
+        _contents.pack_start(self._logo, False, False, self.PADDING)
+        _contents.pack_start(self._name_label, False, False, self.PADDING)
+        _contents.pack_start(self._comments_label, False, False, self.PADDING)
+        _contents.pack_start(self._copyright_label, False, False, self.PADDING)
+        _contents.pack_start(self._writers_contents, False, False, self.PADDING)
+        _contents.pack_start(_license_alignment, False, False, self.PADDING)
+
+        _contents_area = hildon.PannableArea()
+        _contents_area.add_with_viewport(_contents)
+        _contents_area.set_size_request_policy(hildon.SIZE_REQUEST_CHILDREN)
+        self.vbox.add(_contents_area)
+        self.vbox.show_all()
+        self._writers_contents.hide()
+
+    def set_logo(self, logo_path):
+        self._logo.set_from_file(logo_path)
+
+    def set_name(self, name):
+        self._name = name
+        self.set_version(self._version)
+        self.set_title('About %s' % self._name)
+
+    def _set_name_label(self, name):
+        self._name_label.set_markup('<big>%s</big>' % name)
+
+    def set_version(self, version):
+        self._version = version
+        self._set_name_label('%s %s' % (self._name, self._version))
+
+    def set_comments(self, comments):
+        self._comments_label.set_text(comments)
+
+    def set_copyright(self, copyright):
+        self._copyright_label.set_markup('<small>%s</small>' % copyright)
+
+    def set_license(self, license):
+        self._license_label.set_markup('<b>%s</b>\n<small>%s</small>' % \
+                                       ('License:', license))
+
+    def set_authors(self, authors_list):
+        authors = '\n'.join(authors_list)
+        self._writers_label.set_text(authors)
+        self._writers_contents.show_all()
 
 class MovieWindow(hildon.StackableWindow):
 
@@ -324,7 +408,7 @@ class MovieWindow(hildon.StackableWindow):
             label = gtk.Label()
             label.set_markup('<b>%(field)s:</b> <small>%(value)s</small>' %
                              {'field' : key,
-                              'value' : movie.get_value(key)})
+                              'value' : saxutils.escape(movie.get_value(key))})
             label.set_alignment(constants.LEFT_ALIGNMENT,
                                 constants.CENTER_ALIGNMENT)
             side_content.pack_start(label, False, False)
@@ -335,7 +419,7 @@ class MovieWindow(hildon.StackableWindow):
         movie_overview = hildon.TextView()
         movie_overview.set_placeholder('Overview')
         movie_overview.set_wrap_mode(gtk.WRAP_WORD)
-        movie_overview.get_buffer().set_text(movie.get_overview())
+        movie_overview.get_buffer().set_text(saxutils.escape(movie.get_overview()))
 
         label = gtk.Label()
         label.set_markup('<b>Overview:</b>')
